@@ -1,82 +1,83 @@
-## ----style, eval=TRUE, echo=FALSE, results="asis"---------------------------------------
+## ----style, eval=TRUE, echo=FALSE, results="asis"--------------------------
 BiocStyle::latex()
 
-## ----preliminaries, echo=FALSE, message=FALSE-------------------------------------------
+## ----preliminaries, echo=FALSE, message=FALSE------------------------------
 library(GenomeInfoDb)
 library(TxDb.Dmelanogaster.UCSC.dm3.ensGene)
 
-## ----genomeStyles1----------------------------------------------------------------------
+## ----genomeStyles1---------------------------------------------------------
 seqmap <- genomeStyles()
 head(seqmap,n=2)
 
-## ----name-------------------------------------------------------------------------------
+## ----name------------------------------------------------------------------
 names(genomeStyles())
 
-## ----genomeStyles2----------------------------------------------------------------------
+## ----genomeStyles2---------------------------------------------------------
 head(genomeStyles("Homo_sapiens"),5)
 
-## ----style-present----------------------------------------------------------------------
+## ----style-present---------------------------------------------------------
 "UCSC" %in% names(genomeStyles("Homo_sapiens"))
 
-## ----extractSeqlevels-------------------------------------------------------------------
+## ----extractSeqlevels------------------------------------------------------
 extractSeqlevels(species="Arabidopsis_thaliana", style="NCBI")
 
-## ----extractSeqlevelsgroup--------------------------------------------------------------
+## ----extractSeqlevelsgroup-------------------------------------------------
 extractSeqlevelsByGroup(species="Arabidopsis_thaliana", style="NCBI",
                          group="auto")
 
-## ----seqlevelsStyle---------------------------------------------------------------------
+## ----seqlevelsStyle--------------------------------------------------------
 seqlevelsStyle(paste0("chr",c(1:30)))
 seqlevelsStyle(c("2L","2R","X","Xhet"))
 
-## ----keepChr-txdb-----------------------------------------------------------------------
+## ----keepChr-txdb----------------------------------------------------------
 newchr <- paste0("chr",c(1:22,"X","Y","M","1_gl000192_random","4_ctg9_hap1"))
 seqlevelsInGroup(newchr, group="sex")
 seqlevelsInGroup(newchr, group="auto")
 seqlevelsInGroup(newchr, group="circular")
 seqlevelsInGroup(newchr, group="sex","Homo_sapiens","UCSC")
 
-## ----check2-----------------------------------------------------------------------------
+## ----check2----------------------------------------------------------------
 seqnames <- c("chr1", "chr9", "chr2", "chr3", "chr10")
 all(seqnames %in% extractSeqlevels("Homo_sapiens", "UCSC"))
 
-## ----orderSeqlevels---------------------------------------------------------------------
+## ----orderSeqlevels--------------------------------------------------------
 seqnames <- c("chr1","chr9", "chr2", "chr3", "chr10")
 orderSeqlevels(seqnames)
 seqnames[orderSeqlevels(seqnames)]
 
-## ----rankSeqlevels----------------------------------------------------------------------
+## ----rankSeqlevels---------------------------------------------------------
 seqnames <- c("chr1","chr9", "chr2", "chr3", "chr10")
 rankSeqlevels(seqnames)
 
-## ----find-------------------------------------------------------------------------------
+## ----find------------------------------------------------------------------
 mapSeqlevels(c("chrII", "chrIII", "chrM"), "NCBI")
 
-## ----basic-gr---------------------------------------------------------------------------
+## ----basic-gr--------------------------------------------------------------
 gr <- GRanges(paste0("ch",1:35), IRanges(1:35, width=5))
 gr
 
-## ----renameseqlevels--------------------------------------------------------------------
+## ----renameseqlevels-------------------------------------------------------
 newnames <- paste0("chr",1:35)
 names(newnames) <- paste0("ch",1:35)
 head(newnames)
 gr <- renameSeqlevels(gr,newnames)
 gr
 
-## ----dropseqlevels----------------------------------------------------------------------
-dropSeqlevels(gr,paste0("chr",23:35))
+## ----dropseqlevels---------------------------------------------------------
+dropSeqlevels(gr, paste0("chr",23:35), pruning.mode="coarse")
 
-## ----keepseqlevels----------------------------------------------------------------------
-keepSeqlevels(gr, paste0("chr",1:22))
+## ----keepseqlevels---------------------------------------------------------
+keepSeqlevels(gr, paste0("chr",1:22), pruning.mode="coarse")
 
-## ----keepstdchr-------------------------------------------------------------------------
-keepStandardChromosomes(gr)
+## ----keepstdchr------------------------------------------------------------
+keepStandardChromosomes(gr, pruning.mode="coarse")
 
-## ----keepstdchr-2-----------------------------------------------------------------------
+## ----keepstdchr-2----------------------------------------------------------
 plantgr <- GRanges(c(1:5,"MT","Pltd"), IRanges(1:7,width=5))
-keepStandardChromosomes(plantgr, species="Arabidopsis thaliana")
+keepStandardChromosomes(plantgr, species="Arabidopsis thaliana",
+                                 pruning.mode="coarse")
 
-## ----genome-description-class, message=FALSE--------------------------------------------
+## ----genome-description-class, message=FALSE-------------------------------
 library(BSgenome.Celegans.UCSC.ce2)
 class(Celegans)
 is(Celegans, "GenomeDescription")
@@ -89,7 +90,7 @@ provider(gendesc)
 seqinfo(gendesc)
 bsgenomeName(gendesc)
 
-## ----Seqinfo-egs------------------------------------------------------------------------
+## ----Seqinfo-egs-----------------------------------------------------------
 ## Note that all the arguments (except 'genome') must have the
 ## same length. 'genome' can be of length 1, whatever the lengths
 ## of the other arguments are.
@@ -138,13 +139,13 @@ if (interactive()) {
   merge(x, y)  # raises an error
 }
 
-## ----quick-style------------------------------------------------------------------------
+## ----quick-style-----------------------------------------------------------
 txdb <- TxDb.Dmelanogaster.UCSC.dm3.ensGene
 seqlevels(txdb)
 genomeStyles("Drosophila melanogaster")
 mapSeqlevels(seqlevels(txdb), "NCBI")
 
-## ----sequence, eval=FALSE---------------------------------------------------------------
+## ----sequence, eval=FALSE--------------------------------------------------
 #  sequence <- seqlevels(x)
 #  
 #  ## sequence is in UCSC format and we want NCBI style
@@ -159,6 +160,6 @@ mapSeqlevels(seqlevels(txdb), "NCBI")
 #                                  group="auto")
 #  x <- keepSeqlevels(x,auto)
 
-## ----sessionInfo, results='asis', eval=TRUE---------------------------------------------
+## ----sessionInfo, results='asis', eval=TRUE--------------------------------
 toLatex(sessionInfo())
 
